﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using Microsoft.EntityFrameworkCore;
using System.Linq;
using System.Threading.Tasks;

using TestProject.Data;
using TestProject.Models;

namespace TestProject.Pages.Movies
{
    /// <summary>
    /// 편집 모델
    /// </summary>
    public class EditModel : PageModel
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 컨텍스트
        /// </summary>
        private readonly DatabaseContext context;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 영화 - Movie

        /// <summary>
        /// 영화
        /// </summary>
        [BindProperty]
        public Movie Movie { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - EditModel(context)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="context">컨텍스트</param>
        public EditModel(DatabaseContext context)
        {
            this.context = context;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region GET 비동기 처리하기 - OnGetAsync(id)

        /// <summary>
        /// GET 비동기 처리하기
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>액션 결과 태스크</returns>
        public async Task<IActionResult> OnGetAsync(int? id)
        {
            if(id == null)
            {
                return NotFound();
            }

            Movie = await this.context.Movie.FirstOrDefaultAsync(m => m.ID == id);

            if(Movie == null)
            {
                return NotFound();
            }

            return Page();
        }

        #endregion
        #region POST 비동기 처리하기 - OnPostAsync()

        /// <summary>
        /// POST 비동기 처리하기
        /// </summary>
        /// <returns>액션 결과 태스크</returns>
        public async Task<IActionResult> OnPostAsync()
        {
            if(!ModelState.IsValid)
            {
                return Page();
            }

            this.context.Attach(Movie).State = EntityState.Modified;

            try
            {
                await this.context.SaveChangesAsync();
            }
            catch(DbUpdateConcurrencyException)
            {
                if(!MovieExists(Movie.ID))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return RedirectToPage("./Index");
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 영화 존재 여부 구하기 - MovieExists(id)

        /// <summary>
        /// 영화 존재 여부 구하기
        /// </summary>
        /// <param name="id">ID</param>
        /// <returns>영화 존재 여부</returns>
        private bool MovieExists(int id)
        {
            return this.context.Movie.Any(e => e.ID == id);
        }

        #endregion
    }
}